tiled.adapters.sparse.COOAdapter
================================

.. currentmodule:: tiled.adapters.sparse

.. autoclass:: COOAdapter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~COOAdapter.__init__
      ~COOAdapter.from_arrays
      ~COOAdapter.from_coo
      ~COOAdapter.from_global_ref
      ~COOAdapter.read
      ~COOAdapter.read_block
      ~COOAdapter.structure
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~COOAdapter.structure_family
   
   